==> radiance-ui-2.0.2.tgz: package/lib/shared-components/accordion/thumbnails/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import { Container, ImageContainer, ThumbnailImage, MultiplesContainer, MultiplesText } from './style';

var Thumbnails =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Thumbnails, _React$Component);

  function Thumbnails() {
    _classCallCheck(this, Thumbnails);

    return _possibleConstructorReturn(this, _getPrototypeOf(Thumbnails).apply(this, arguments));
  }

  _createClass(Thumbnails, [{
    key: "renderThumbnails",
    value: function renderThumbnails() {
      var photoSrcs = this.props.photoSrcs;

      if (photoSrcs.length === 0) {
        return null;
      }

      var firstThumbnail = React.createElement(ImageContainer, null, React.createElement(ThumbnailImage, {
        src: photoSrcs[0]
      }));
      var secondThumbnail = null;

      if (photoSrcs.length === 2) {
        secondThumbnail = React.createElement(ImageContainer, null, React.createElement(ThumbnailImage, {
          src: photoSrcs[1]
        }));
      } else if (photoSrcs.length > 2) {
        secondThumbnail = React.createElement(MultiplesContainer, null, React.createElement(MultiplesText, null, "+", photoSrcs.length - 1));
      }

      return React.createElement(React.Fragment, null, firstThumbnail, secondThumbnail);
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(Container, null, this.renderThumbnails());
    }
  }]);

  return Thumbnails;
}(React.Component);

Thumbnails.propTypes = {
  photoSrcs: PropTypes.arrayOf(PropTypes.string).isRequired
};
export default Thumbnails;

==> radiance-ui-2.0.7.tgz: package/lib/shared-components/accordion/thumbnails/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import { Container, ImageContainer, ThumbnailImage, MultiplesContainer, MultiplesText } from './style';

var Thumbnails =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Thumbnails, _React$Component);

  function Thumbnails() {
    _classCallCheck(this, Thumbnails);

    return _possibleConstructorReturn(this, _getPrototypeOf(Thumbnails).apply(this, arguments));
  }

  _createClass(Thumbnails, [{
    key: "renderThumbnails",
    value: function renderThumbnails() {
      var photoSrcs = this.props.photoSrcs;

      if (photoSrcs.length === 0) {
        return null;
      }

      var firstThumbnail = ___EmotionJSX(ImageContainer, null, ___EmotionJSX(ThumbnailImage, {
        src: photoSrcs[0]
      }));

      var secondThumbnail = null;

      if (photoSrcs.length === 2) {
        secondThumbnail = ___EmotionJSX(ImageContainer, null, ___EmotionJSX(ThumbnailImage, {
          src: photoSrcs[1]
        }));
      } else if (photoSrcs.length > 2) {
        secondThumbnail = ___EmotionJSX(MultiplesContainer, null, ___EmotionJSX(MultiplesText, null, "+", photoSrcs.length - 1));
      }

      return ___EmotionJSX(React.Fragment, null, firstThumbnail, secondThumbnail);
    }
  }, {
    key: "render",
    value: function render() {
      return ___EmotionJSX(Container, null, this.renderThumbnails());
    }
  }]);

  return Thumbnails;
}(React.Component);

Thumbnails.propTypes = {
  photoSrcs: PropTypes.arrayOf(PropTypes.string).isRequired
};
export default Thumbnails;
